from trajectory_msgs.msg import JointTrajectory, JointTrajectoryPoint
from builtin_interfaces.msg import Duration
from rclpy.node import Node

from hexapod_python.ik import ik

import time


class IKPublisherNode(Node):
    def __init__(self, node_name = "ik_publisher"):
        super().__init__(node_name)

        self.leg_groups_ = [ "e1", "e2", "e3", "e4", "e5", "e6"]
        self.create_leg_publishers()

    def create_leg_publishers(self):
        self.publisher_ = {}
        for leg in self.leg_groups_:            
            controller_topic = f"/{leg}_group_controller/joint_trajectory"
            self.publisher_[leg] = self.create_publisher(JointTrajectory, controller_topic , 10)

        # wait for the controller to subscribe
        print("Waiting for subscribers")
        for leg in self.leg_groups_:
            while self.count_subscribers(f"/{leg}_group_controller/joint_trajectory") == 0:                    
                time.sleep(0.1)


    def publish_ik_values(self, ik_values):
        for leg in self.leg_groups_:
            t = 0
            joint_trajectory_points = []
            for i in ik_values:
                joint_trajectory_points.append(
                    JointTrajectoryPoint(
                        positions = i[leg],
                        time_from_start = Duration(nanosec = t%50 * 20000000 , sec = int(t/50))
                    )
                )
                t += 1


            group_num = leg[1:]
            trajectory = JointTrajectory(
                joint_names = [ f"c{group_num}_joint", f"f{group_num}_joint", f"t{group_num}_joint" ],
                points = joint_trajectory_points
            )
            self.publisher_[leg].publish(trajectory)
