from trajectory_msgs.msg import JointTrajectory, JointTrajectoryPoint
from builtin_interfaces.msg import Duration
import rclpy
from rclpy.node import Node

import time

class JTCPublisher(Node):
    def __init__(self):
            super().__init__('jtc_publisher')

            self.group_tags_ = [ "e1", "e2", "e3", "e4", "e5", "e6"]
            
            self.publisher_ = {}
            trajectory = {}

            for tag in self.group_tags_:
            
                group_num = tag[1:]
                controller_topic = f"/{tag}_group_controller/joint_trajectory"
                print(controller_topic, tag, group_num)

                direction = 1
                if int(group_num)>3:
                    direction = -1

                self.publisher_[tag] = self.create_publisher(JointTrajectory, controller_topic , 10)
                trajectory[tag] = JointTrajectory(
                    joint_names = [ f"c{group_num}_joint", f"f{group_num}_joint", f"t{group_num}_joint" ],
                    points = [ 
                            JointTrajectoryPoint (time_from_start = Duration(sec = 1), positions = [direction * 0,    direction * -1.4, direction *   0]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 2), positions = [direction * -0.3, direction * -1.3, direction *   0]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 3), positions = [direction * 0,    direction * -1.4, direction * 0.5]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 4), positions = [direction * -0.3, direction * -1.3, direction *   0]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 5), positions = [direction * -0.5, direction * -1.3, direction *   0.6]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 6), positions = [direction * -0.3, direction * -1.3, direction *   0.6]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 7), positions = [direction * -0.5, direction * -1.3, direction *   0.6]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 8), positions = [direction * -0.5, direction * -1.3, direction *   0]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 9), positions = [direction * -0.3, direction * -1.3, direction *   0]),
                            JointTrajectoryPoint (time_from_start = Duration(sec = 10), positions =[direction *    0, direction * -1.4, direction *   0]),
                    ]
                )
            
            for tag in self.group_tags_:
                while self.count_subscribers(f"/{tag}_group_controller/joint_trajectory") == 0:                    
                    time.sleep(0.1)

            for tag in self.group_tags_:
                self.publisher_[tag].publish(trajectory[tag])

def main(args = None):
    rclpy.init(args=args)

    jtc_publisher = JTCPublisher()
    rclpy.spin(jtc_publisher)
    jtc_publisher.destroy_node()
    rclpy.shutdown()
    